#!/bin/csh -f

# test pma, illustrate fallback to conventional memory allocator (driver)
# Copyright (C) 2022  Terence Kelly
# Contact:  tpkelly @ { acm.org, cs.princeton.edu, eecs.umich.edu }
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


set b  = test6
set bf = pma_backing_file

alias clean "rm -f $b $bf out1 out2"

clean

if ("clean" == $1) then
    exit
endif

unlimit coredumpsize

if ( $?PMAALLWARNINGS ) then
    set warningflags = `gawk '{print $1}' gcc_warnings_final`
else
    echo
    echo '****************************************'
    echo '*** using bare minimum warning flags ***'
    echo '****************************************'
    set warningflags = '-Wall -Wextra'
endif

echo ; echo '= = = = = = = = = = compile for warnings'  ; echo
rm -f $b ; gcc -std=c99 -O3 $warningflags -o $b $b.c pma.c
echo ; echo '= = = = = = = = = = compile for debugging' ; echo
rm -f $b ; gcc -std=c99 -g  $warningflags -o $b $b.c pma.c

echo ; echo '= = = = = = = = = = run with conventional allocator under "valgrind -q"' ; echo

valgrind -q ./$b one too free fore NULL > out1

echo ; echo '= = = = = = = = = = run with pma' ; echo

# create backing file; must be multiple of system page size
truncate -s 409600 $bf

./$b one  $bf  > out2
./$b too  $bf >> out2
./$b free $bf >> out2
./$b fore $bf >> out2

echo ; echo '= = = = = = = = = = diff outputs (should be empty)'
diff out1 out2
echo '= = = = = = = = = = cat output'
cat out1
echo '= = = = = = = = = = done' ; echo

if ("keep" == $1) then
    exit
endif

clean

